**gridjug** is a light-weight wrapper to run Jug with GridMap on a Grid Engine cluster.

It stands on the shoulder of the giants `Jug`_ and `GridMap`_.
Please credit *their* authors accordingly.

|today| (Version |release|)

Andreas Sorge <gridjug@asorge.de>

- `Max Planck Institute for Dynamics & Self-Organization <http://www.ds.mpg.de/en>`_, Göttingen, Germany
- Organization for Research on Complex Adaptive Systems, Göttingen, Germany

Citation
--------

Please cite as: Andreas Sorge. (2015). gridjug |release|. Zenodo. |DOI|

Please also cite `Jug`_ and `GridMap`_.

Documentation license
---------------------

|CC| This documentation is licensed under a `Creative Commons Attribution 4.0 International License`_.

.. _Creative Commons Attribution 4.0 International License: http://creativecommons.org/licenses/by/4.0/


.. _Jug: http://luispedro.org/software/jug/
.. _GridMap: http://github.com/pygridtools/gridmap

.. |DOI| image:: https://zenodo.org/badge/6089/andsor/gridjug.svg
         :target: https://zenodo.org/badge/latestdoi/6089/andsor/gridjug

.. |CC| image:: _static/cc-by.*
